pub struct VcrdAttribute {
pub id: u32,
pub iv: Vec<u8>,
pub data: Vec<u8>,
}Expand description
One VAULT_VCRD attribute’s encrypted payload.
iv is empty when the attribute carries no IV (impacket then uses AES-CBC
with a zero IV); data is the AES-CBC ciphertext.
Fields
id: u32iv: Vec<u8>data: Vec<u8>Trait Implementations
Sourceimpl Clone for VcrdAttribute
impl Clone for VcrdAttribute
Sourcefn clone(&self) -> VcrdAttribute
fn clone(&self) -> VcrdAttribute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VcrdAttribute
impl Debug for VcrdAttribute
impl Eq for VcrdAttribute
Sourceimpl PartialEq for VcrdAttribute
impl PartialEq for VcrdAttribute
Sourcefn eq(&self, other: &VcrdAttribute) -> bool
fn eq(&self, other: &VcrdAttribute) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VcrdAttribute